# Frigidaire Python API

This is an API wrapper written in Python around the Frigidaire 2.0 App.

This was created specifically for use in [home-assistant/core](https://github.com/home-assistant/core) to introduce HomeKit support to Frigidaire air conditioners.
